# biometrics

Package to generate sample based biometrics

[![Build Status](https://travis-ci.com/msk-access/biometrics.svg?branch=master)](https://travis-ci.com/msk-access/biometrics) [![PyPi](https://img.shields.io/pypi/v/biometrics.svg?)](https://pypi.python.org/pypi/biometrics)

* Free software: Apache Software License 2.0
* Documentation: https://msk-access.gitbook.io/biometrics/
* GitHub: https://github.com/msk-access/biometrics/

## Installation

From pypi:

`pip install biometrics`

From conda (python v3.6 only):

`conda create -n myenv -c bioconda -c conda-forge -c msk-access python=3.6 biometrics`
